# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/raw_logs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"yandex/cloud/cdn/v1/raw_logs.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1dyandex/cloud/validation.proto\"v\n\x0fRawLogsSettings\x12#\n\x0b\x62ucket_name\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024\x12\x1f\n\rbucket_region\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\x0b\x66ile_prefix\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50*\xa4\x01\n\rRawLogsStatus\x12\x1f\n\x1bRAW_LOGS_STATUS_UNSPECIFIED\x10\x00\x12!\n\x1dRAW_LOGS_STATUS_NOT_ACTIVATED\x10\x01\x12\x16\n\x12RAW_LOGS_STATUS_OK\x10\x02\x12\x1a\n\x16RAW_LOGS_STATUS_FAILED\x10\x03\x12\x1b\n\x17RAW_LOGS_STATUS_PENDING\x10\x04\x42V\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.raw_logs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _RAWLOGSSETTINGS.fields_by_name['bucket_name']._options = None
  _RAWLOGSSETTINGS.fields_by_name['bucket_name']._serialized_options = b'\350\3071\001\212\3101\006<=1024'
  _RAWLOGSSETTINGS.fields_by_name['bucket_region']._options = None
  _RAWLOGSSETTINGS.fields_by_name['bucket_region']._serialized_options = b'\212\3101\004<=50'
  _RAWLOGSSETTINGS.fields_by_name['file_prefix']._options = None
  _RAWLOGSSETTINGS.fields_by_name['file_prefix']._serialized_options = b'\212\3101\004<=50'
  _globals['_RAWLOGSSTATUS']._serialized_start=211
  _globals['_RAWLOGSSTATUS']._serialized_end=375
  _globals['_RAWLOGSSETTINGS']._serialized_start=90
  _globals['_RAWLOGSSETTINGS']._serialized_end=208
# @@protoc_insertion_point(module_scope)
