# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/sqlserver/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.sqlserver.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.sqlserver.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.sqlserver.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_database__pb2
from yandex.cloud.mdb.sqlserver.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_user__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2016sp2_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2016sp2__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2017_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2017__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2019_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2019__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/mdb/sqlserver/v1/cluster_service.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/type/timeofday.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a*yandex/cloud/mdb/sqlserver/v1/backup.proto\x1a+yandex/cloud/mdb/sqlserver/v1/cluster.proto\x1a,yandex/cloud/mdb/sqlserver/v1/database.proto\x1a(yandex/cloud/mdb/sqlserver/v1/user.proto\x1a;yandex/cloud/mdb/sqlserver/v1/config/sqlserver2016sp2.proto\x1a\x38yandex/cloud/mdb/sqlserver/v1/config/sqlserver2017.proto\x1a\x38yandex/cloud/mdb/sqlserver/v1/config/sqlserver2019.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"i\n\x14ListClustersResponse\x12\x38\n\x08\x63lusters\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.sqlserver.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb7\x06\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12G\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x32.yandex.cloud.mdb.sqlserver.v1.Cluster.Environment\x12>\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.ConfigSpec\x12\x43\n\x0e\x64\x61tabase_specs\x18\x07 \x03(\x0b\x32+.yandex.cloud.mdb.sqlserver.v1.DatabaseSpec\x12;\n\nuser_specs\x18\x08 \x03(\x0b\x32\'.yandex.cloud.mdb.sqlserver.v1.UserSpec\x12;\n\nhost_specs\x18\t \x03(\x0b\x32\'.yandex.cloud.mdb.sqlserver.v1.HostSpec\x12\x1c\n\nnetwork_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x12\x1f\n\x0csqlcollation\x18\r \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x16\n\x0ehost_group_ids\x18\x0e \x03(\t\x12\x1a\n\x12service_account_id\x18\x0f \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x86\x04\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12>\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.ConfigSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xd3\x05\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12$\n\x04name\x18\x04 \x01(\tB\x16\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x06 \x03(\x0b\x32@.yandex.cloud.mdb.sqlserver.v1.RestoreClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12G\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x32.yandex.cloud.mdb.sqlserver.v1.Cluster.Environment\x12>\n\x0b\x63onfig_spec\x18\x08 \x01(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.ConfigSpec\x12;\n\nhost_specs\x18\t \x03(\x0b\x32\'.yandex.cloud.mdb.sqlserver.v1.HostSpec\x12\x1c\n\nnetwork_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tfolder_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x0c \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\r \x01(\x08\x12\x16\n\x0ehost_group_ids\x18\x0e \x03(\t\x12\x1a\n\x12service_account_id\x18\x0f \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"]\n\x1bStartClusterFailoverRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\thost_name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=253\"2\n\x1cStartClusterFailoverMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xb2\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x46\n\x07message\x18\x02 \x03(\x0b\x32\x35.yandex.cloud.mdb.sqlserver.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdd\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12W\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x41.yandex.cloud.mdb.sqlserver.v1.ListClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1e\n\x16\x61lways_next_page_token\x18\x08 \x01(\x08\x12\x1a\n\x06\x66ilter\x18\t \x01(\tB\n\x8a\xc8\x31\x06<=1000\"[\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSQLSERVER_ERROR\x10\x01\x12\x19\n\x15SQLSERVER_APPLICATION\x10\x02\"j\n\x17ListClusterLogsResponse\x12\x36\n\x04logs\x18\x01 \x03(\x0b\x32(.yandex.cloud.mdb.sqlserver.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"m\n\x1aListClusterBackupsResponse\x12\x36\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32%.yandex.cloud.mdb.sqlserver.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"g\n\x18ListClusterHostsResponse\x12\x32\n\x05hosts\x18\x01 \x03(\x0b\x32#.yandex.cloud.mdb.sqlserver.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"D\n\x1aUpdateClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\\\n\x08HostSpec\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\tsubnet_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\"t\n\x0eUpdateHostSpec\x12\x17\n\thost_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\"\x8f\x01\n\x19UpdateClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12P\n\x11update_host_specs\x18\x02 \x03(\x0b\x32-.yandex.cloud.mdb.sqlserver.v1.UpdateHostSpecB\x06\x82\xc8\x31\x02>0\"\xb2\x08\n\nConfigSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x82\x01\n\x1bsqlserver_config_2016sp2std\x18\x02 \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2016sp2stdH\x00R\x1asqlserverConfig_2016sp2std\x12\x82\x01\n\x1bsqlserver_config_2016sp2ent\x18\x05 \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2016sp2entH\x00R\x1asqlserverConfig_2016sp2ent\x12y\n\x18sqlserver_config_2017std\x18\x08 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2017stdH\x00R\x17sqlserverConfig_2017std\x12y\n\x18sqlserver_config_2017ent\x18\t \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2017entH\x00R\x17sqlserverConfig_2017ent\x12y\n\x18sqlserver_config_2019std\x18\n \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019stdH\x00R\x17sqlserverConfig_2019std\x12y\n\x18sqlserver_config_2019ent\x18\x0b \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019entH\x00R\x17sqlserverConfig_2019ent\x12;\n\tresources\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.sqlserver.v1.Resources\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12\x35\n\x06\x61\x63\x63\x65ss\x18\x06 \x01(\x0b\x32%.yandex.cloud.mdb.sqlserver.v1.Access\x12`\n\x15secondary_connections\x18\x07 \x01(\x0e\x32\x41.yandex.cloud.mdb.sqlserver.v1.ClusterConfig.SecondaryConnectionsB\x12\n\x10sqlserver_config2\xc4\x17\n\x0e\x43lusterService\x12\x90\x01\n\x03Get\x12\x30.yandex.cloud.mdb.sqlserver.v1.GetClusterRequest\x1a&.yandex.cloud.mdb.sqlserver.v1.Cluster\"/\x82\xd3\xe4\x93\x02)\x12\'/mdb/sqlserver/v1/clusters/{cluster_id}\x12\x93\x01\n\x04List\x12\x32.yandex.cloud.mdb.sqlserver.v1.ListClustersRequest\x1a\x33.yandex.cloud.mdb.sqlserver.v1.ListClustersResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/mdb/sqlserver/v1/clusters\x12\xab\x01\n\x06\x43reate\x12\x33.yandex.cloud.mdb.sqlserver.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1f\"\x1a/mdb/sqlserver/v1/clusters:\x01*\x12\xb8\x01\n\x06Update\x12\x33.yandex.cloud.mdb.sqlserver.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,2\'/mdb/sqlserver/v1/clusters/{cluster_id}:\x01*\x12\xc3\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.mdb.sqlserver.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)*\'/mdb/sqlserver/v1/clusters/{cluster_id}\x12\xb8\x01\n\x05Start\x12\x32.yandex.cloud.mdb.sqlserver.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02/\"-/mdb/sqlserver/v1/clusters/{cluster_id}:start\x12\xb4\x01\n\x04Stop\x12\x31.yandex.cloud.mdb.sqlserver.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02.\",/mdb/sqlserver/v1/clusters/{cluster_id}:stop\x12\xb7\x01\n\x04Move\x12\x31.yandex.cloud.mdb.sqlserver.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\",/mdb/sqlserver/v1/clusters/{cluster_id}:move:\x01*\x12\xbc\x01\n\x06\x42\x61\x63kup\x12\x33.yandex.cloud.mdb.sqlserver.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x30\"./mdb/sqlserver/v1/clusters/{cluster_id}:backup\x12\xb6\x01\n\x07Restore\x12\x34.yandex.cloud.mdb.sqlserver.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\'\"\"/mdb/sqlserver/v1/clusters:restore:\x01*\x12\xdb\x01\n\rStartFailover\x12:.yandex.cloud.mdb.sqlserver.v1.StartClusterFailoverRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*\'\n\x1cStartClusterFailoverMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02:\"5/mdb/sqlserver/v1/clusters/{cluster_id}:startFailover:\x01*\x12\xaf\x01\n\x08ListLogs\x12\x35.yandex.cloud.mdb.sqlserver.v1.ListClusterLogsRequest\x1a\x36.yandex.cloud.mdb.sqlserver.v1.ListClusterLogsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/mdb/sqlserver/v1/clusters/{cluster_id}:logs\x12\xc7\x01\n\x0eListOperations\x12;.yandex.cloud.mdb.sqlserver.v1.ListClusterOperationsRequest\x1a<.yandex.cloud.mdb.sqlserver.v1.ListClusterOperationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/mdb/sqlserver/v1/clusters/{cluster_id}/operations\x12\xbb\x01\n\x0bListBackups\x12\x38.yandex.cloud.mdb.sqlserver.v1.ListClusterBackupsRequest\x1a\x39.yandex.cloud.mdb.sqlserver.v1.ListClusterBackupsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//mdb/sqlserver/v1/clusters/{cluster_id}/backups\x12\xb3\x01\n\tListHosts\x12\x36.yandex.cloud.mdb.sqlserver.v1.ListClusterHostsRequest\x1a\x37.yandex.cloud.mdb.sqlserver.v1.ListClusterHostsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/mdb/sqlserver/v1/clusters/{cluster_id}/hosts\x12\xe7\x01\n\x0bUpdateHosts\x12\x38.yandex.cloud.mdb.sqlserver.v1.UpdateClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*3\n\x1aUpdateClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02>\"9/mdb/sqlserver/v1/clusters/{cluster_id}/hosts:batchUpdate:\x01*Bv\n!yandex.cloud.api.mdb.sqlserver.v1B\x04PSCSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.sqlserver.v1B\004PSCSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver'
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATECLUSTERREQUEST_LABELSENTRY._options = None
  _CREATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['name']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _CREATECLUSTERREQUEST.fields_by_name['description']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['sqlcollation']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['sqlcollation']._serialized_options = b'\212\3101\005<=100'
  _UPDATECLUSTERREQUEST_LABELSENTRY._options = None
  _UPDATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BACKUPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _BACKUPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTORECLUSTERREQUEST_LABELSENTRY._options = None
  _RESTORECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _RESTORECLUSTERREQUEST.fields_by_name['backup_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _RESTORECLUSTERREQUEST.fields_by_name['time']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['time']._serialized_options = b'\350\3071\001'
  _RESTORECLUSTERREQUEST.fields_by_name['name']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*'
  _RESTORECLUSTERREQUEST.fields_by_name['description']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _RESTORECLUSTERREQUEST.fields_by_name['labels']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _RESTORECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _RESTORECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _STARTCLUSTERFAILOVERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERFAILOVERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STARTCLUSTERFAILOVERREQUEST.fields_by_name['host_name']._options = None
  _STARTCLUSTERFAILOVERREQUEST.fields_by_name['host_name']._serialized_options = b'\212\3101\005<=253'
  _LOGRECORD_MESSAGEENTRY._options = None
  _LOGRECORD_MESSAGEENTRY._serialized_options = b'8\001'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERBACKUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _MOVECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _HOSTSPEC.fields_by_name['zone_id']._options = None
  _HOSTSPEC.fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _HOSTSPEC.fields_by_name['subnet_id']._options = None
  _HOSTSPEC.fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATEHOSTSPEC.fields_by_name['host_name']._options = None
  _UPDATEHOSTSPEC.fields_by_name['host_name']._serialized_options = b'\350\3071\001'
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['update_host_specs']._options = None
  _UPDATECLUSTERHOSTSREQUEST.fields_by_name['update_host_specs']._serialized_options = b'\202\3101\002>0'
  _CLUSTERSERVICE.methods_by_name['Get']._options = None
  _CLUSTERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/mdb/sqlserver/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['List']._options = None
  _CLUSTERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/mdb/sqlserver/v1/clusters'
  _CLUSTERSERVICE.methods_by_name['Create']._options = None
  _CLUSTERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002\037\"\032/mdb/sqlserver/v1/clusters:\001*'
  _CLUSTERSERVICE.methods_by_name['Update']._options = None
  _CLUSTERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002,2\'/mdb/sqlserver/v1/clusters/{cluster_id}:\001*'
  _CLUSTERSERVICE.methods_by_name['Delete']._options = None
  _CLUSTERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002)*\'/mdb/sqlserver/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['Start']._options = None
  _CLUSTERSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\002/\"-/mdb/sqlserver/v1/clusters/{cluster_id}:start'
  _CLUSTERSERVICE.methods_by_name['Stop']._options = None
  _CLUSTERSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\002.\",/mdb/sqlserver/v1/clusters/{cluster_id}:stop'
  _CLUSTERSERVICE.methods_by_name['Move']._options = None
  _CLUSTERSERVICE.methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0021\",/mdb/sqlserver/v1/clusters/{cluster_id}:move:\001*'
  _CLUSTERSERVICE.methods_by_name['Backup']._options = None
  _CLUSTERSERVICE.methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\0020\"./mdb/sqlserver/v1/clusters/{cluster_id}:backup'
  _CLUSTERSERVICE.methods_by_name['Restore']._options = None
  _CLUSTERSERVICE.methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002\'\"\"/mdb/sqlserver/v1/clusters:restore:\001*'
  _CLUSTERSERVICE.methods_by_name['StartFailover']._options = None
  _CLUSTERSERVICE.methods_by_name['StartFailover']._serialized_options = b'\262\322*\'\n\034StartClusterFailoverMetadata\022\007Cluster\202\323\344\223\002:\"5/mdb/sqlserver/v1/clusters/{cluster_id}:startFailover:\001*'
  _CLUSTERSERVICE.methods_by_name['ListLogs']._options = None
  _CLUSTERSERVICE.methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\002.\022,/mdb/sqlserver/v1/clusters/{cluster_id}:logs'
  _CLUSTERSERVICE.methods_by_name['ListOperations']._options = None
  _CLUSTERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0024\0222/mdb/sqlserver/v1/clusters/{cluster_id}/operations'
  _CLUSTERSERVICE.methods_by_name['ListBackups']._options = None
  _CLUSTERSERVICE.methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0021\022//mdb/sqlserver/v1/clusters/{cluster_id}/backups'
  _CLUSTERSERVICE.methods_by_name['ListHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\002/\022-/mdb/sqlserver/v1/clusters/{cluster_id}/hosts'
  _CLUSTERSERVICE.methods_by_name['UpdateHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['UpdateHosts']._serialized_options = b'\262\322*3\n\032UpdateClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002>\"9/mdb/sqlserver/v1/clusters/{cluster_id}/hosts:batchUpdate:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=671
  _globals['_GETCLUSTERREQUEST']._serialized_end=724
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=727
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=871
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=873
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=978
  _globals['_CREATECLUSTERREQUEST']._serialized_start=981
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1804
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1759
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1804
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1806
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1849
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1852
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2370
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1759
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1804
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2372
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2415
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2417
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2473
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2475
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2518
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=2520
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=2576
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=2578
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=2621
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=2624
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=3347
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=1759
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=1804
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=3349
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=3412
  _globals['_STARTCLUSTERFAILOVERREQUEST']._serialized_start=3414
  _globals['_STARTCLUSTERFAILOVERREQUEST']._serialized_end=3507
  _globals['_STARTCLUSTERFAILOVERMETADATA']._serialized_start=3509
  _globals['_STARTCLUSTERFAILOVERMETADATA']._serialized_end=3559
  _globals['_LOGRECORD']._serialized_start=3562
  _globals['_LOGRECORD']._serialized_end=3740
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=3694
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=3740
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=3743
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=4220
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=4129
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=4220
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=4222
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=4328
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=4330
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=4456
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=4458
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=4569
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=4571
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=4694
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=4696
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=4805
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=4807
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=4928
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=4930
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=5033
  _globals['_STARTCLUSTERREQUEST']._serialized_start=5035
  _globals['_STARTCLUSTERREQUEST']._serialized_end=5090
  _globals['_STARTCLUSTERMETADATA']._serialized_start=5092
  _globals['_STARTCLUSTERMETADATA']._serialized_end=5134
  _globals['_STOPCLUSTERREQUEST']._serialized_start=5136
  _globals['_STOPCLUSTERREQUEST']._serialized_end=5190
  _globals['_STOPCLUSTERMETADATA']._serialized_start=5192
  _globals['_STOPCLUSTERMETADATA']._serialized_end=5233
  _globals['_MOVECLUSTERREQUEST']._serialized_start=5235
  _globals['_MOVECLUSTERREQUEST']._serialized_end=5334
  _globals['_MOVECLUSTERMETADATA']._serialized_start=5336
  _globals['_MOVECLUSTERMETADATA']._serialized_end=5434
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_start=5436
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_end=5504
  _globals['_HOSTSPEC']._serialized_start=5506
  _globals['_HOSTSPEC']._serialized_end=5598
  _globals['_UPDATEHOSTSPEC']._serialized_start=5600
  _globals['_UPDATEHOSTSPEC']._serialized_end=5716
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_start=5719
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_end=5862
  _globals['_CONFIGSPEC']._serialized_start=5865
  _globals['_CONFIGSPEC']._serialized_end=6939
  _globals['_CLUSTERSERVICE']._serialized_start=6942
  _globals['_CLUSTERSERVICE']._serialized_end=9954
# @@protoc_insertion_point(module_scope)
