# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/config_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/loadtesting/api/v1/config_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/operation/operation.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\"W\n\x13\x43reateConfigRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\x0byaml_string\x18\x02 \x01(\tH\x00\x42\x08\n\x06\x63onfig\")\n\x14\x43reateConfigMetadata\x12\x11\n\tconfig_id\x18\x01 \x01(\t2\xc4\x01\n\rConfigService\x12\xb2\x01\n\x06\x43reate\x12\x34.yandex.cloud.loadtesting.api.v1.CreateConfigRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*%\n\x14\x43reateConfigMetadata\x12\rconfig.Config\x82\xd3\xe4\x93\x02 \"\x1b/loadtesting/api/v1/configs:\x01*Bv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.config_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting'
  _CREATECONFIGREQUEST.fields_by_name['folder_id']._options = None
  _CREATECONFIGREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CONFIGSERVICE.methods_by_name['Create']._options = None
  _CONFIGSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*%\n\024CreateConfigMetadata\022\rconfig.Config\202\323\344\223\002 \"\033/loadtesting/api/v1/configs:\001*'
  _globals['_CREATECONFIGREQUEST']._serialized_start=224
  _globals['_CREATECONFIGREQUEST']._serialized_end=311
  _globals['_CREATECONFIGMETADATA']._serialized_start=313
  _globals['_CREATECONFIGMETADATA']._serialized_end=354
  _globals['_CONFIGSERVICE']._serialized_start=357
  _globals['_CONFIGSERVICE']._serialized_end=553
# @@protoc_insertion_point(module_scope)
